@@ -26,7 +26,7 @@ def loss_fn(outputs, targets):
     return torch.nn.CrossEntropyLoss()(outputs, targets)
 
 
-def train(model, optimizer, train_dataloader, test_dataloader, epochs):
+def custom_trainer(model, optimizer, train_dataloader, test_dataloader, epochs):
     '''
     custom training module
     '''
@@ -40,9 +40,9 @@ def train(model, optimizer, train_dataloader, test_dataloader, epochs):
         for _, batch in tqdm(enumerate(train_dataloader)):
             # import pdb; pdb.set_trace();
             model.zero_grad(set_to_none=True)
-            ids = batch['ids'].squeeze(1).to(DEVICE)
-            mask = batch['mask'].squeeze(1).to(DEVICE)
-            type_ids = batch['type_ids'].squeeze(1).to(DEVICE)
+            ids = batch['input_ids'].squeeze(1).to(DEVICE)
+            mask = batch['attention_mask'].squeeze(1).to(DEVICE)
+            type_ids = batch['token_type_ids'].squeeze(1).to(DEVICE)
             label = batch['label'].to(DEVICE)
             output = model(ids, mask, type_ids)
 
@@ -60,8 +60,8 @@ def train(model, optimizer, train_dataloader, test_dataloader, epochs):
         avg_train_loss = total_train_loss / len(train_dataloader)
         avg_train_accuracy = total_train_accuracy / len(train_dataloader)
         print(f'''
-            Training loss: {avg_train_loss} || 
-            Training accuracy: {avg_train_accuracy} || 
+            Training loss: {avg_train_loss} ||
+            Training accuracy: {avg_train_accuracy} ||
             Training time: {time.time() - epoch_start} seconds
             ''')
         print('Evaluation in progress...')
@@ -69,8 +69,8 @@ def train(model, optimizer, train_dataloader, test_dataloader, epochs):
         avg_val_loss = np.array(val_loss).mean()
         avg_val_accuracy = accuracy_metrics(val_outputs, val_targets)
         print(f'''
-            Validation loss: {avg_val_loss} || 
-            Validation accuracy: {avg_val_accuracy} || 
+            Validation loss: {avg_val_loss} ||
+            Validation accuracy: {avg_val_accuracy} ||
             Validation time: {time.time() - epoch_start} seconds
             ''')
         save_checkpoint(model, optimizer, epoch, avg_train_loss, avg_train_accuracy, avg_val_loss, avg_val_accuracy)
@@ -84,9 +84,9 @@ def validate(model, test_dataloader):
     val_targets, val_outputs, val_loss = [], [], []
     with torch.no_grad():
         for _, batch in enumerate(test_dataloader):
-            ids = batch['ids'].squeeze(1).to(DEVICE)
-            mask = batch['mask'].squeeze(1).to(DEVICE)
-            type_ids = batch['type_ids'].squeeze(1).to(DEVICE)
+            ids = batch['input_ids'].squeeze(1).to(DEVICE)
+            mask = batch['attention_mask'].squeeze(1).to(DEVICE)
+            type_ids = batch['token_type_ids'].squeeze(1).to(DEVICE)
             label = batch['label'].to(DEVICE)
             outputs = model(ids, mask, type_ids)
             val_targets.extend(label.detach().cpu().numpy())
